@@ -25,7 +25,7 @@ from .engine_intf import GenericStreamWrapper, BytesIOWrapper
 from .proto_handlers import load_protocol_handler
 from .utils.connect import connect_to_database, dataframe_to_sql, db_conn_flavor
 from .utils.csp_connect import connect_to_csp
-from .utils.dbconn import sql_enquote_id
+from .sql.misc import sql_enquote_id
 from .utils.df_utils import CloseAfterIteration, load_dataframe_from_sql, LoadStrategy
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options
 from .utils.format_sniffer import find_url_extension, detect_format, FORMAT_ALIASES_WRITE_OPTIONS
@@ -613,6 +613,8 @@ class DSLibrary(object):
             # write data to an SQL table
             sql_source = sql_source or resource_name
             db_conn = self.get_sql_connection(sql_source, database=kwargs.get("database"))
+            if not sql_flavor:
+                sql_flavor = db_conn_flavor(db_conn)
             content = _coerce_to_dataframe(content)
             try:
                 table = sql_table or resource_name
