@@ -52,7 +52,7 @@ class TestRunLocal(unittest.TestCase):
         r = ModelRunner.infer_command_from_path("abc.r")
         assert r == ['RScript', 'abc.r'], r
         r = ModelRunner.infer_command_from_path("abc.ipynb")
-        assert r == ['nbconvert', '--to', 'notebook', '--execute', '--inplace', 'abc.ipynb'], r
+        self.assertEqual(r, ['nbconvert', '--to', 'notebook', '--execute', '--log-level=ERROR', '--inplace', 'abc.ipynb'])
 
     def test_supply_and_capture_data(self):
         """
