@@ -1,6 +1,6 @@
 import unittest
 from dslibrary.utils import dbconn
-from dslibrary.utils.dbconn import sql_enquote_id
+from dslibrary.sql.misc import sql_enquote_id
 
 
 class TestDBConn(unittest.TestCase):
